@@ -2,23 +2,23 @@
  *   Copyright (C) 2010 Ivan Cukic <ivan.cukic(at)kde.org>
  *
  *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
+ *   it under the terms of the GNU Lesser General Public License version 2,
  *   or (at your option) any later version, as published by the Free
  *   Software Foundation
  *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
+ *   GNU Lesser General Public License for more details
  *
- *   You should have received a copy of the GNU General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this program; if not, write to the
  *   Free Software Foundation, Inc.,
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef ACTIVITIES_MANAGER_P_
-#define ACTIVITIES_MANAGER_P_
+#ifndef ACTIVITIES_MANAGER_P
+#define ACTIVITIES_MANAGER_P
 
 #include "activitymanager_interface.h"
 
@@ -49,4 +49,5 @@ private:
 
 } // namespace KActivities
 
-#endif // ACTIVITIES_MANAGER_P_
+#endif // ACTIVITIES_MANAGER_P
+
